# coding=utf-8
from unittest import TestCase
import os
import tempfile

from earthdiagnostics.earthdiags import EarthDiags
from earthdiagnostics.utils import TempFile
from earthdiagnostics import cdftools
from mock import Mock


class TestEarthDiags(TestCase):

    def setUp(self):
        self.earthdiags = EarthDiags()

    def test_clean(self):
        self.earthdiags.config.scratch_dir = tempfile.mkdtemp()
        os.makedirs(os.path.join(self.earthdiags.config.scratch_dir, 'extra_folder'))

        self.assertTrue(os.path.isdir(self.earthdiags.config.scratch_dir))
        self.earthdiags.clean()
        self.assertFalse(os.path.isdir(self.earthdiags.config.scratch_dir))

    def test_clean_link(self):
        temp_folder = tempfile.mkdtemp()
        scratch_dir = tempfile.mktemp()
        os.symlink(temp_folder, scratch_dir)
        os.makedirs(os.path.join(temp_folder, 'extra_folder'))
        self.earthdiags.config.scratch_dir = scratch_dir

        self.assertTrue(os.path.islink(self.earthdiags.config.scratch_dir))
        self.assertTrue(os.path.isdir(temp_folder))
        self.earthdiags.clean()
        self.assertFalse(os.path.islink(self.earthdiags.config.scratch_dir))
        self.assertFalse(os.path.isdir(temp_folder))

    def test_read_config(self):
        self.earthdiags.config = Mock()
        self.earthdiags.config.scratch_dir = 'scratch_path'
        self.earthdiags.config.cdftools_path = 'cdftools_path'
        self.earthdiags.config.data_convention = 'SPECS'

        self.earthdiags.read_config('config/path')

        self.earthdiags.config.parse.assert_called_once_with('config/path')
        self.assertEqual(os.environ['HDF5_USE_FILE_LOCKING'], 'FALSE')
        self.assertEqual(self.earthdiags.config.scratch_dir, TempFile.scratch_folder)
        self.assertEqual(self.earthdiags.config.cdftools_path, cdftools.path)
        self.assertDictEqual(self.earthdiags.dic_variables,
                             {'nav_lat': 'lat',
                              'nav_lev': 'lev',
                              'nav_lon': 'lon',
                              't': 'time',
                              'time_counter': 'time',
                              'x': 'i',
                              'y': 'j',
                              'z': 'lev'})

    def test_read_config_primavera(self):
        self.earthdiags.config = Mock()
        self.earthdiags.config.scratch_dir = 'scratch_path'
        self.earthdiags.config.cdftools_path = 'cdftools_path'
        self.earthdiags.config.data_convention = 'PRIMAVERA'

        self.earthdiags.read_config('config/path')

        self.earthdiags.config.parse.assert_called_once_with('config/path')
        self.assertEqual(os.environ['HDF5_USE_FILE_LOCKING'], 'FALSE')
        self.assertEqual(self.earthdiags.config.scratch_dir, TempFile.scratch_folder)
        self.assertEqual(self.earthdiags.config.cdftools_path, cdftools.path)
        self.assertDictEqual(self.earthdiags.dic_variables,
                             {'nav_lat': 'latitude',
                              'nav_lev': 'lev',
                              'nav_lon': 'longitude',
                              't': 'time',
                              'time_counter': 'time',
                              'x': 'i',
                              'y': 'j',
                              'z': 'lev'})
